@@ -1,28 +1,16 @@
 /*
- * This file is part of the KFileMetaData project
- * Copyright (C) 2016  Varun Joshi <varunj.1011@gmail.com>
- * Copyright (C) 2015  Boudhayan Gupta <bgupta@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    This file is part of the KFileMetaData project
+    SPDX-FileCopyrightText: 2016 Varun Joshi <varunj.1011@gmail.com>
+    SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #include "externalextractor.h"
 #include "kfilemetadata_debug.h"
+#include "properties.h"
+#include "propertyinfo.h"
+#include "typeinfo.h"
 
 #include <QDir>
 #include <QProcess>
@@ -30,10 +18,6 @@
 #include <QJsonObject>
 #include <QJsonArray>
 
-#include "properties.h"
-#include "propertyinfo.h"
-#include "typeinfo.h"
-
 #define EXTRACTOR_TIMEOUT_MS 30000
 
 using namespace KFileMetaData;
@@ -54,7 +38,7 @@ ExternalExtractor::ExternalExtractor(QObject* parent)
 }
 
 ExternalExtractor::ExternalExtractor(const QString& pluginPath)
-    : ExtractorPlugin(new QObject()),
+    : ExtractorPlugin(nullptr),
       d_ptr(new ExternalExtractorPrivate)
 {
     Q_D(ExternalExtractor);
@@ -62,10 +46,10 @@ ExternalExtractor::ExternalExtractor(const QString& pluginPath)
     d->path = pluginPath;
 
     QDir pluginDir(pluginPath);
-    QStringList pluginDirContents = pluginDir.entryList();
+    QStringList pluginDirContents = pluginDir.entryList(QDir::Files | QDir::NoDotAndDotDot);
 
     if (!pluginDirContents.contains(QStringLiteral("manifest.json"))) {
-        qCDebug(KFILEMETADATA_LOG) << "Path does not seem to contain a valid plugin";
+        qCDebug(KFILEMETADATA_LOG) << pluginPath << "does not seem to contain a valid plugin";
         return;
     }
 
@@ -78,9 +62,11 @@ ExternalExtractor::ExternalExtractor(const QString& pluginPath)
     }
 
     QJsonObject rootObject = manifestDoc.object();
-    QJsonArray mimetypesArray = rootObject.value(QStringLiteral("mimetypes")).toArray();
+    const QJsonArray mimetypesArray = rootObject.value(QStringLiteral("mimetypes")).toArray();
     QStringList mimetypes;
-    Q_FOREACH(const QVariant &mimetype, mimetypesArray) {
+    mimetypes.reserve(mimetypesArray.count());
+
+     for (const QJsonValue &mimetype : mimetypesArray) {
         mimetypes << mimetype.toString();
     }
 
@@ -115,6 +101,13 @@ void ExternalExtractor::extract(ExtractionResult* result)
 
     QProcess extractorProcess;
     extractorProcess.start(d->mainPath, QStringList(), QIODevice::ReadWrite);
+    bool started = extractorProcess.waitForStarted();
+    if (!started) {
+        qCWarning(KFILEMETADATA_LOG) << "External extractor" << d->mainPath
+            << "failed to start:" << extractorProcess.errorString();
+        return;
+    }
+
     extractorProcess.write(writeData.toJson());
     extractorProcess.closeWriteChannel();
     extractorProcess.waitForFinished(EXTRACTOR_TIMEOUT_MS);
@@ -123,7 +116,8 @@ void ExternalExtractor::extract(ExtractionResult* result)
     errorOutput = extractorProcess.readAllStandardError();
 
     if (extractorProcess.exitStatus()) {
-        qCDebug(KFILEMETADATA_LOG) << errorOutput;
+        qCWarning(KFILEMETADATA_LOG) << "External extractor" << d->mainPath
+            << "failed to index" << result->inputUrl() << "-" << errorOutput;
         return;
     }
 
@@ -137,24 +131,26 @@ void ExternalExtractor::extract(ExtractionResult* result)
     QJsonObject rootObject = extractorData.object();
     QJsonObject propertiesObject = rootObject[QStringLiteral("properties")].toObject();
 
-    Q_FOREACH(const auto &key, propertiesObject.keys()) {
-        if (key == QStringLiteral("typeInfo")) {
-            TypeInfo info = TypeInfo::fromName(propertiesObject.value(key).toString());
+    const auto propertiesObjectEnd = propertiesObject.constEnd();
+    auto i = propertiesObject.constBegin();
+    for (; i != propertiesObjectEnd; ++i) {
+        if (i.key() == QStringLiteral("typeInfo")) {
+            TypeInfo info = TypeInfo::fromName(propertiesObject.value(i.key()).toString());
             result->addType(info.type());
             continue;
         }
 
         // for plaintext extraction
-        if (key == QStringLiteral("text")) {
-            result->append(propertiesObject.value(key).toString(QStringLiteral("")));
+        if (i.key() == QStringLiteral("text")) {
+            result->append(propertiesObject.value(i.key()).toString(QStringLiteral("")));
             continue;
         }
 
-        PropertyInfo info = PropertyInfo::fromName(key);
-        if (info.name() != key) {
+        PropertyInfo info = PropertyInfo::fromName(i.key());
+        if (info.name() != i.key()) {
             continue;
         }
-        result->add(info.property(), propertiesObject.value(key).toVariant());
+        result->add(info.property(), i.value().toVariant());
     }
 
     if (rootObject[QStringLiteral("status")].toString() != QStringLiteral("OK")) {
