@@ -1,24 +1,12 @@
 /*
-    <one line to give the library's name and an idea of what it does.>
-    Copyright (C) 2013  Vishesh Handa <me@vhanda.in>
+    SPDX-FileCopyrightText: 2013 Vishesh Handa <me@vhanda.in>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 
 #include "office2007extractor.h"
+#include <memory>
 
 #include <KZip>
 
@@ -34,15 +22,20 @@ Office2007Extractor::Office2007Extractor(QObject* parent)
 
 }
 
+const QStringList supportedMimeTypes = {
+    QStringLiteral("application/vnd.openxmlformats-officedocument.wordprocessingml.document"),
+    QStringLiteral("application/vnd.openxmlformats-officedocument.wordprocessingml.template"),
+    QStringLiteral("application/vnd.openxmlformats-officedocument.presentationml.presentation"),
+    QStringLiteral("application/vnd.openxmlformats-officedocument.presentationml.slide"),
+    QStringLiteral("application/vnd.openxmlformats-officedocument.presentationml.slideshow"),
+    QStringLiteral("application/vnd.openxmlformats-officedocument.presentationml.template"),
+    QStringLiteral("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"),
+    QStringLiteral("application/vnd.openxmlformats-officedocument.spreadsheetml.template"),
+};
 
 QStringList Office2007Extractor::mimetypes() const
 {
-    QStringList list;
-    list << QStringLiteral("application/vnd.openxmlformats-officedocument.wordprocessingml.document")
-         << QStringLiteral("application/vnd.openxmlformats-officedocument.presentationml.presentation")
-         << QStringLiteral("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
-
-    return list;
+    return supportedMimeTypes;
 }
 
 void Office2007Extractor::extract(ExtractionResult* result)
@@ -72,11 +65,12 @@ void Office2007Extractor::extract(ExtractionResult* result)
     }
 
     const KArchiveDirectory* docPropDirectory = dynamic_cast<const KArchiveDirectory*>(docPropEntry);
-    const QStringList docPropsEntries = docPropDirectory->entries();
 
-    if (docPropsEntries.contains(QStringLiteral("core.xml"))) {
+    const bool extractMetaData = result->inputFlags() & ExtractionResult::ExtractMetaData;
+
+    const KArchiveFile* file = docPropDirectory->file(QStringLiteral("core.xml"));
+    if (extractMetaData && file) {
         QDomDocument coreDoc(QStringLiteral("core"));
-        const KArchiveFile* file = static_cast<const KArchiveFile*>(docPropDirectory->entry(QStringLiteral("core.xml")));
         coreDoc.setContent(file->data());
 
         QDomElement docElem = coreDoc.documentElement();
@@ -85,7 +79,7 @@ void Office2007Extractor::extract(ExtractionResult* result)
         if (!elem.isNull()) {
             QString str = elem.text();
             if (!str.isEmpty()) {
-                result->add(Property::Comment, str);
+                result->add(Property::Description, str);
             }
         }
 
@@ -117,14 +111,14 @@ void Office2007Extractor::extract(ExtractionResult* result)
         if (!elem.isNull()) {
             QString str = elem.text();
             if (!str.isEmpty()) {
-                result->add(Property::Langauge, str);
+                result->add(Property::Language, str);
             }
         }
 
         elem = docElem.firstChildElement(QStringLiteral("dcterms:created"));
         if (!elem.isNull()) {
             QString str = elem.text();
-            QDateTime dt = dateTimeFromString(elem.text());
+            QDateTime dt = dateTimeFromString(str);
             if (!dt.isNull()) {
                 result->add(Property::CreationDate, dt);
             }
@@ -139,9 +133,9 @@ void Office2007Extractor::extract(ExtractionResult* result)
         }
     }
 
-    if (docPropsEntries.contains(QStringLiteral("app.xml"))) {
+    file = docPropDirectory->file(QStringLiteral("app.xml"));
+    if (extractMetaData && file) {
         QDomDocument appDoc(QStringLiteral("app"));
-        const KArchiveFile* file = static_cast<const KArchiveFile*>(docPropDirectory->entry(QStringLiteral("app.xml")));
         appDoc.setContent(file->data());
 
         QDomElement docElem = appDoc.documentElement();
@@ -198,10 +192,12 @@ void Office2007Extractor::extract(ExtractionResult* result)
         const QStringList wordEntries = wordDirectory->entries();
 
         if (wordEntries.contains(QStringLiteral("document.xml"))) {
-            QDomDocument appDoc(QStringLiteral("document"));
-            const KArchiveFile* file = static_cast<const KArchiveFile*>(wordDirectory->entry(QStringLiteral("document.xml")));
+            const KArchiveFile* file = wordDirectory->file(QStringLiteral("document.xml"));
 
-            extractTextWithTag(file->createDevice(), QStringLiteral("w:t"), result);
+            if (file) {
+                std::unique_ptr<QIODevice> contentIODevice{file->createDevice()};
+                extractTextWithTag(contentIODevice.get(), QStringLiteral("w:t"), result);
+            }
         }
     }
 
@@ -259,19 +255,22 @@ void Office2007Extractor::extractAllText(QIODevice* device, ExtractionResult* re
 void Office2007Extractor::extractTextFromFiles(const KArchiveDirectory* archiveDir, ExtractionResult* result)
 {
     const QStringList entries = archiveDir->entries();
-    foreach(const QString & entryName, entries) {
+    for (const QString & entryName : entries) {
         const KArchiveEntry* entry = archiveDir->entry(entryName);
+        if (!entry) {
+            continue;
+        }
         if (entry->isDirectory()) {
             const KArchiveDirectory* subDir = dynamic_cast<const KArchiveDirectory*>(entry);
             extractTextFromFiles(subDir, result);
             continue;
         }
 
-        if (!entryName.endsWith(QLatin1String(".xml")))
-            continue;
-
-        const KArchiveFile* file = static_cast<const KArchiveFile*>(entry);
-        extractAllText(file->createDevice(), result);
+        if (entry->isFile() && entryName.endsWith(QLatin1String(".xml"))) {
+            const KArchiveFile* file = static_cast<const KArchiveFile*>(entry);
+            std::unique_ptr<QIODevice> contentIODevice{file->createDevice()};
+            extractAllText(contentIODevice.get() , result);
+        }
     }
 }
 
